<?php
/**
 * Kunena Component
 *
 * JoomSpirit template based on Crypsis template
 * version 1.0
 * date 2017-08
 *
 * @license     https://www.gnu.org/copyleft/gpl.html GNU/GPL
 *
 **/
defined('_JEXEC') or die;


class KunenaTemplateJoomspirit extends KunenaTemplate
{
	/**
	 * List of parent template names.
	 *
	 * This template will automatically search for missing files from listed parent templates.
	 * The feature allows you to create one base template and only override changed files.
	 *
	 * @var array
	 */
	protected $default = array('joomspirit');

	/**
	 * Template initialization.
	 *
	 * @return void
	 */
	public function initialize()
	{
		// Template requires Bootstrap javascript
		JHtml::_('bootstrap.framework');
		JHtml::_('bootstrap.tooltip', '[data-toggle="tooltip"]');

		// Template also requires jQuery framework.
		JHtml::_('jquery.framework');
		JHtml::_('bootstrap.modal');

		// Load JavaScript.
		$this->addScript('assets/js/main.js');

		$this->ktemplate = KunenaFactory::getTemplate();
		$storage = $this->ktemplate->params->get('storage');

		if ($storage)
		{
			$this->addScript('assets/js/localstorage.js');
		}

		// Compile CSS from LESS files.
		$this->compileLess('assets/less/crypsis.less', 'kunena.css');
		$this->addStyleSheet('kunena.css');

		$filenameless = JPATH_SITE . '/components/com_kunena/template/joomspirit/assets/less/custom.less';

		if (file_exists($filenameless) && 0 != filesize($filenameless))
		{
			$this->compileLess('assets/less/custom.less', 'kunena-custom.css');
			$this->addStyleSheet('kunena-custom.css');
		}

		$filename = JPATH_SITE . '/components/com_kunena/template/joomspirit/assets/css/custom.css';

		if (file_exists($filename))
		{
			$this->addStyleSheet('assets/css/custom.css');
		}

		$bootstrap = $this->ktemplate->params->get('bootstrap');
		$doc = JFactory::getDocument();

		if ($bootstrap)
		{
			$doc->addStyleSheet(JUri::base(true) . '/media/jui/css/bootstrap.min.css');
			$doc->addStyleSheet(JUri::base(true). '/media/jui/css/bootstrap-extended.css');
			$doc->addStyleSheet(JUri::base(true) . '/media/jui/css/bootstrap-responsive.min.css');

			if ($this->ktemplate->params->get('icomoon'))
			{
				$doc->addStyleSheet(JUri::base(true) . '/media/jui/css/icomoon.css');
			}
		}

		$fontawesome = $this->ktemplate->params->get('fontawesome');

		if ($fontawesome)
		{
			$doc->addStyleSheet("https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css");
		}
		
		// Load JoomSpirt CSS file 
		$this->addStyleSheet('assets/css/joomspirit.css');

		// Load template colors settings
		$styles = <<<EOF
		/* Kunena Custom CSS */
EOF;
		$iconcolornew = $this->ktemplate->params->get('IconColorNew');

		if ($iconcolornew)
		{
			$styles .= <<<EOF
		.layout#kunena [class*="category"] .knewchar { color: {$iconcolornew} !important; }
		.layout#kunena sup.knewchar { color: {$iconcolornew} !important; }
		.layout#kunena .topic-item-unread { border-left-color: {$iconcolornew} !important;}
		.layout#kunena .topic-item-unread .icon { color: {$iconcolornew} !important;}
		.layout#kunena .topic-item-unread i.fa { color: {$iconcolornew} !important;}
		#kunena .table > tbody > tr > td.js-knewchar { border-left-color: {$iconcolornew} ;}
		#kunena td.js-knewchar > div > h3, #kunena td.js-knewchar > div > h3 > a, #kunena td.js-knewchar > div > h3 > a:hover,
		#kunena div.js-unread a, #kunena div.js-unread a:hover { color: {$iconcolornew} ;}
EOF;
		}
		
		$bg_color_h1 = $this->ktemplate->params->get('bg_color_h1');

		if ($bg_color_h1)
		{
			$styles .= <<<EOF
		#kunena.layout h1, #kunena.layout .js-forum-head,
		#kunena ul.nav.nav-tabs a:hover, #kunena ul.nav.nav-tabs a:focus, ul#KunenaUserEdit .active > a,
		#kunena ul.nav.nav-tabs .active > a,
		#kunena.layout .navbar ul[class="nav"] > li > a:hover, #kunena.layout .navbar ul[class="nav"] > li > a:focus,
		#kunena.layout .navbar ul[class="nav"] > li.active > a { background: {$bg_color_h1}; }
EOF;
		}
		
		$color_title = $this->ktemplate->params->get('color_title');

		if ($color_title)
		{
			$styles .= <<<EOF
		#kunena h2, #kunena h2 > a, span.icon,
		#kunena h2 > a:hover, #kunena h2 > a:hover span,
		#kunena h3, #kunena h3 > a, #kunena h3 > a:hover,
		#kunena a, #kunena a:hover { color: {$color_title}; }
EOF;
		}
		

		$document = JFactory::getDocument();
		$document->addStyleDeclaration($styles);

		parent::initialize();
	}

	/**
	 * @param        $filename
	 * @param   string $group
	 *
	 * @return JDocument
	 */
	public function addStyleSheet($filename, $group = 'forum')
	{
		$filename = $this->getFile($filename, false, '', "media/kunena/cache/{$this->name}/css");

		return JFactory::getDocument()->addStyleSheet(JUri::root(true) . "/{$filename}");
	}
}
